---

### Search and Sort Modules

---
<section data-markdown>

Different Search and Sort algorithms
are implemented.


For now the functionality is really basic
but it should evolve to a collection of
several methods for searching elements 
and / or sorting sequences.


HowTo:

1) find index number of a element in a list
  (here the binary search method is applied)
    
```python
    from SeaSor import SeaSor
    
    get_index = SeaSor.Search().bin_index(array, target)
```




##### For more informations and instructions visit:
https://github.com/m1ghtfr3e/SearchSort

</section>
